Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(67)

Unified Diff: net/quic/quic_session_test.cc

Issue 355573007: Land Recent QUIC Changes. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: added NET_EXPORT_PRIVATE for ContainsQuicTag Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/quic/quic_session.cc ('k') | net/quic/quic_unacked_packet_map.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/quic/quic_session_test.cc
diff --git a/net/quic/quic_session_test.cc b/net/quic/quic_session_test.cc
index 134cd252a0875eb16ed8ad2dfc6b545702cdf6d6..9cb235d9fc2476fe95229faaccca760ae424a5c6 100644
--- a/net/quic/quic_session_test.cc
+++ b/net/quic/quic_session_test.cc
@@ -631,7 +631,7 @@ TEST_P(QuicSessionTest, MultipleRstStreamsCauseSingleConnectionClose) {
TEST_P(QuicSessionTest, HandshakeUnblocksFlowControlBlockedStream) {
// Test that if a stream is flow control blocked, then on receipt of the SHLO
// containing a suitable send window offset, the stream becomes unblocked.
- if (version() < QUIC_VERSION_17) {
+ if (version() <= QUIC_VERSION_16) {
return;
}
@@ -864,7 +864,7 @@ TEST_P(QuicSessionTest, ConnectionFlowControlAccountingRstAfterRst) {
TEST_P(QuicSessionTest, FlowControlWithInvalidFinalOffset) {
// Test that if we receive a stream RST with a highest byte offset that
// violates flow control, that we close the connection.
- if (version() < QUIC_VERSION_17) {
+ if (version() <= QUIC_VERSION_16) {
return;
}
ValueRestore<bool> old_flag(&FLAGS_enable_quic_connection_flow_control_2,
@@ -904,9 +904,9 @@ TEST_P(QuicSessionTest, VersionNegotiationDisablesFlowControl) {
EXPECT_TRUE(stream->flow_controller()->IsEnabled());
EXPECT_TRUE(session_.flow_controller()->IsEnabled());
// Version 17 implies that stream flow control is enabled, but connection
// level is disabled.
- session_.OnSuccessfulVersionNegotiation(QUIC_VERSION_17);
+ session_.OnSuccessfulVersionNegotiation(QUIC_VERSION_18);
EXPECT_FALSE(session_.flow_controller()->IsEnabled());
EXPECT_TRUE(stream->flow_controller()->IsEnabled());
« no previous file with comments | « net/quic/quic_session.cc ('k') | net/quic/quic_unacked_packet_map.h » ('j') | no next file with comments »
@@ -904,9 +904,9 @@ TEST_P(QuicSessionTest, VersionNegotiationDisablesFlowControl) {
EXPECT_TRUE(stream->flow_controller()->IsEnabled());
EXPECT_TRUE(session_.flow_controller()->IsEnabled());
- // Version 17 implies that stream flow control is enabled, but connection
+ // Version 18 implies that stream flow control is enabled, but connection
// level is disabled.

Powered by Google App Engine
This is Rietveld 408576698